/*
  Copyright (c) Members of the EGEE Collaboration. 2004. 
  See http://www.eu-egee.org/partners/ for details on the copyright
  holders.  
  
  Licensed under the Apache License, Version 2.0 (the "License"); 
  you may not use this file except in compliance with the License. 
  You may obtain a copy of the License at 
  
      http://www.apache.org/licenses/LICENSE-2.0 
  
  Unless required by applicable law or agreed to in writing, software 
  distributed under the License is distributed on an "AS IS" BASIS, 
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
  See the License for the specific language governing permissions and 
  limitations under the License.
*/

#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include <stdbool.h>
#include <sys/types.h>
#include <unistd.h>

#include <string>
#include <iostream>
#include <fstream>
#include <regex.h>

//#define _GNU_SOURCE
//#include <cstring>

using namespace std;

string toLower( const string& source ) {
  
  char str[source.length()+1];
  
  memset( (void*)str, 0, source.length()+1 );
  
  for (int i=0 ;i<source.length( ); i++) 
    str[i] = tolower( (int)source.at(i) );
  
  return str;
}

/* -------------------------------------------------------------------------------------------------------
Author: Luigi Zangrando

glite-ce-cream-purge-proxy.c

EXAMPLE DIRECTORY TO PURGE: 
/opt/glite/var/cream_sandbox/<VO>/<DN>/proxy/<filename>

THIS IS A SIPLE COMMAND TO DELETE THE EXPIRE DELEGATION PROXY.

To Compile you can siple type from a shell:
 
shell>  cc glite-ce-cream-purge-proxy.c -o glite-ce-cream-purge-proxy

TO DO AS root:
shell> chown root.tomcat glite-ce-cream-purge-proxy
shell> chmod 4550 glite-ce-cream-purge-proxy


#####################################################################
INPUT --- THREE INPUT PARAMETER:
--- the VO
--- the DN (Distinguish Name)
--- The filename (the proxy file name)
#####################################################################

#####################################################################
OUTPUP --- POSSIBLE OUTPUT:
- if you do not pass the three imput parameters: Error: The arguments of this command must be 3: VO DN JobID
- Error: can't open the configuration file. Please if the file /opt/glite/etc/glite-ce-cream/cream-config.xml exists and it has the right permission
- rm: cannot remove `/opt/glite/var/cream_sandbox/<VO>/<DN>/proxy/<filename>': Permission denied (check the right permission of this command file) 
- NONE the command is executed without any problems. If the file doesn't exist the command deletes nothing
#####################################################################
   
------------------------------------------------------------------------------------------------------------------ */

int main ( int argc, char *argv[] )	{ 

  int returnCommand;

  // Variables used to retrieve the absolute path in the Cream configuration file
  char tmpParsingString[100];
  std::string absolutePath;
  
  //FILE *fileConf;
  bool found = false;
  string CreamSandboxDir("cream_sandbox_dir");
  string ConfigurationFile("/etc/glite-ce-cream/cream-config.xml");

  if (argc != 4) {
     fprintf(stderr, "Error: The arguments of this command must be 3: VO DN filename\n");
     return 1;
  }

  // these are the three input parameters of the Command 
  
  string inputVO 		 = argv[1];
  string inputDN 		 = argv[2];
  string inputProxyFileName 	 = argv[3];

  // open the Cream Configuration file
  
  ifstream fileConf(ConfigurationFile.c_str());
  string buffer;
  
  
  while ( !fileConf.eof() ) {
    char buf[2048];
    
    fileConf.getline( buf, 2048 );
    
    buffer = buf;
    
    string lbuffer( toLower(buffer) );
    
    string::size_type pos1 = lbuffer.find( CreamSandboxDir );
    
    if(pos1 != string::npos ) {
      string savebuf = buffer;
      buffer = buffer.substr( pos1 + CreamSandboxDir.length() + 1, buffer.length() - pos1 -1  );
      
      string::size_type pos2 = buffer.find("value");
      
      if(pos2 == string::npos) {
      
        cerr << "Malformed line [" << savebuf << "]: parameter CREAM_SANDBOX_DIR not followed by 'value=...'" << endl;
      
        return 1;
      }
      
      pos2 = buffer.find_first_not_of(" \t=\"", pos2 + 5 );
      
      buffer = buffer.substr( pos2, buffer.length() - pos2);
      
      pos2 = buffer.find('\"' );
      
      absolutePath = buffer.substr(0,pos2);
      
      if( absolutePath.at(0) != '/' )
        absolutePath = string("/") + absolutePath;
      
      found = true;
      break;
    }
  }

  if(!found ) {
    cerr << "No attribute CREAM_SANDBOX_DIR in configuration file " << ConfigurationFile << endl;
    return 1;
  }

  std::string commandExe = "rm -rf ";
  
  commandExe += absolutePath + "/" + inputVO + "/" + inputDN + "/proxy/" + inputProxyFileName;

  setuid(0);
  returnCommand = system(commandExe.c_str());
 
  return 0;
}

